@@ -86,7 +86,6 @@ EXCLUDE = (
     "cmd/tools/cvtgxl.c",
     "cmd/tools/dijkstra.c",
     "cmd/tools/gc.c",
-    "cmd/tools/gml2gv.c",
     "cmd/tools/gml2gv.h",
     "cmd/tools/graph_generator.c",
     "cmd/tools/graphml2gv.c",
@@ -219,7 +218,6 @@ EXCLUDE = (
     "lib/dotgen/dot.h",
     "lib/dotgen/dotinit.c",
     "lib/dotgen/dotprocs.h",
-    "lib/dotgen/dotsplines.c",
     "lib/dotgen/fastgr.c",
     "lib/dotgen/flat.c",
     "lib/dotgen/mincross.c",
@@ -310,14 +308,11 @@ EXCLUDE = (
     "lib/gvc/gvtool_tred.c",
     "lib/gvc/gvusershape.c",
     "lib/gvpr/actions.h",
-    "lib/gvpr/compile.c",
     "lib/gvpr/compile.h",
     "lib/gvpr/gdefs.h",
     "lib/gvpr/gprstate.c",
     "lib/gvpr/gprstate.h",
-    "lib/gvpr/gvpr.c",
     "lib/gvpr/gvpr.h",
-    "lib/gvpr/parse.c",
     "lib/gvpr/parse.h",
     "lib/gvpr/trie.c",
     "lib/gvpr/trieFA.h",
@@ -423,8 +418,6 @@ EXCLUDE = (
     "lib/ortho/trapezoid.c",
     "lib/osage/osage.h",
     "lib/osage/osageinit.c",
-    "lib/pack/ccomps.c",
-    "lib/pack/pack.c",
     "lib/pack/pack.h",
     "lib/patchwork/patchwork.c",
     "lib/patchwork/patchwork.h",
@@ -575,18 +568,14 @@ EXCLUDE = (
     "plugin/webp/gvloadimage_webp.c",
     "plugin/webp/gvplugin_webp.c",
     "plugin/xlib/gvdevice_xlib.c",
-    "tclpkg/gdtclft/gdtclft.c",
     "tclpkg/gv/gv_builtins.c",
     "tclpkg/gv/gv_dummy_init.c",
     "tclpkg/gv/gv_java_init.c",
     "tclpkg/gv/gv_php_init.c",
     "tclpkg/gv/gv_tcl_init.c",
     "tclpkg/tcldot/no_builtins.c",
-    "tclpkg/tcldot/tcldot-edgecmd.c",
-    "tclpkg/tcldot/tcldot-graphcmd.c",
     "tclpkg/tcldot/tcldot-id.c",
     "tclpkg/tcldot/tcldot-io.c",
-    "tclpkg/tcldot/tcldot-nodecmd.c",
     "tclpkg/tcldot/tcldot-util.c",
     "tclpkg/tcldot/tcldot.h",
     "tclpkg/tcldot/tcldot_builtins.cpp",
