@@ -15,7 +15,6 @@
 
 #include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/startswith.h>
 #include <common/types.h>
 #include <common/utils.h>
 #include "convert.h"
@@ -23,6 +22,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <util/alloc.h>
+#include <util/startswith.h>
 
 #define EMPTY(s)	((s == 0) || (*s == '\0'))
 #define SLEN(s)     (sizeof(s)-1)
