@@ -32,12 +32,6 @@ extern "C" {
 
 #define elementsof(x)   (sizeof(x)/sizeof(x[0]))
 
-    extern char *pathpath(const char *);
-    extern char *pathfind(const char *, const char *, const char *);
-    extern char *pathaccess(const char*, const char*, const char*);
-    extern const char *pathcat(agxbuf *, const char *, const char *,
-			 const char *);
-
     extern int chresc(const char *, char **);
     extern int chrtoi(const char *);
     extern char *fmtesq(const char *, const char *);
