@@ -24,8 +24,8 @@
 #include <ctype.h>
 #include <cgraph/cghdr.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/strcasecmp.h>
 #include <inttypes.h>
+#include <util/strcasecmp.h>
 
 #define EMPTY(s)		(((s) == 0) || (s)[0] == '\0')
 #define MAX(a,b)     ((a)>(b)?(a):(b))
@@ -392,16 +392,34 @@ static int write_trl(Agraph_t * g, iochan_t * ofile)
     return 0;
 }
 
+/// is this graph unnamed?
+///
+/// @param g Graph to inspect
+/// @return True if this graph was given no explicit name
+static bool is_anonymous(Agraph_t *g) {
+  assert(g != NULL);
+
+  // handle the common case inline for performance
+  if (AGDISC(g, id) == &AgIdDisc) {
+    // replicate `idprint`
+    const IDTYPE id = AGID(g);
+    if (id % 2 != 0) {
+      return true;
+    }
+    return *(char *)(uintptr_t)id == LOCALNAMEPREFIX;
+  }
+
+  const char *const name = agnameof(g);
+  return name == NULL || name[0] == LOCALNAMEPREFIX;
+}
+
 static bool irrelevant_subgraph(Agraph_t * g)
 {
     int i, n;
     Agattr_t *sdata, *pdata, *rdata;
     Agdatadict_t *dd;
 
-    char *name;
-
-    name = agnameof(g);
-    if (name && name[0] != LOCALNAMEPREFIX)
+    if (!is_anonymous(g))
 	return false;
     if ((sdata = agattrrec(g)) && (pdata = agattrrec(agparent(g)))) {
 	rdata = agattrrec(agroot(g));
@@ -421,9 +439,10 @@ static bool irrelevant_subgraph(Agraph_t * g)
 
 static bool node_in_subg(Agraph_t * g, Agnode_t * n)
 {
-    Agraph_t *subg;
+    Agraphs_t *subgs = g_seq2(g);
 
-    for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
+    for (size_t i = 0; i < Agraphs_size(subgs); ++i) {
+	Agraph_t *subg = Agraphs_get(subgs, i);
 	if (irrelevant_subgraph(subg))
 	    continue;
 	if (agsubnode(subg, n, 0))
@@ -626,10 +645,11 @@ static int write_port(Agedge_t * e, iochan_t * ofile, Agsym_t * port)
 }
 
 static bool write_edge_test(Agraph_t *g, Agedge_t *e) {
-    Agraph_t *subg;
+    Agraphs_t *subgs = g_seq2(g);
 
     /* can use agedge() because we subverted the dict compar_f */
-    for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
+    for (size_t i = 0; i < Agraphs_size(subgs); ++i) {
+	Agraph_t *subg = Agraphs_get(subgs, i);
 	if (irrelevant_subgraph(subg))
 	    continue;
 	if (agsubedge(subg, e, 0))
