@@ -24,11 +24,11 @@
 #include <common/colorprocs.h>
 #include <common/colortbl.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/gv_math.h>
-#include <cgraph/strcasecmp.h>
-#include <cgraph/unreachable.h>
+#include <util/alloc.h>
+#include <util/strcasecmp.h>
+#include <util/unreachable.h>
 
 static char* colorscheme;
 
@@ -126,18 +126,6 @@ static int colorcmpf(const void *p0, const void *p1)
   return strcasecmp(p0, ((const hsvrgbacolor_t *)p1)->name);
 }
 
-char *canontoken(char *str)
-{
-    agxbuf canon = {0};
-    char c, *p;
-
-    p = str;
-    while ((c = *p++)) {
-	agxbputc(&canon, gv_tolower(c));
-    }
-    return agxbdisown(&canon);
-}
-
 /* fullColor:
  * Return "/prefix/str"
  */
@@ -182,19 +170,17 @@ static char *fullColor(agxbuf *xb, const char *prefix, const char *str) {
 #define DFLT_SCHEME_LEN ((sizeof(DFLT_SCHEME)-1)/sizeof(char))
 #define ISNONDFLT(s) ((s) && *(s) && strncasecmp(DFLT_SCHEME, s, DFLT_SCHEME_LEN-1))
 
-static char* resolveColor (char* str)
-{
-    char* s;
-    char* ss;   /* second slash */
-    char* c2;   /* second char */
+static char *resolveColor(const char *str) {
+    const char *s;
 
     if (!strcmp(str, "black")) return strdup(str);
     if (!strcmp(str, "white")) return strdup(str);
     if (!strcmp(str, "lightgrey")) return strdup(str);
     agxbuf xb = {0};
     if (*str == '/') {   /* if begins with '/' */
-	c2 = str+1;
-        if ((ss = strchr(c2, '/'))) {  /* if has second '/' */
+	const char *const c2 = str + 1; // second char
+        const char *const ss = strchr(c2, '/'); // second slash
+        if (ss != NULL) { // if has second '/'
 	    if (*c2 == '/') {    /* if second '/' is second character */
 		    /* Do not compare against final '/' */
 		if (ISNONDFLT(colorscheme))
@@ -214,27 +200,23 @@ static char* resolveColor (char* str)
     return on_heap;
 }
 
-int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
-{
-    static hsvrgbacolor_t *last;
-    char *p;
+int colorxlate(const char *str, gvcolor_t *color, color_type_t target_type) {
     char c;
     double H, S, V, A, R, G, B;
-    unsigned int r, g, b, a;
-    int rc;
+    unsigned int r, g, b;
 
     color->type = target_type;
 
-    rc = COLOR_OK;
+    int rc = COLOR_OK;
     for (; *str == ' '; str++);	/* skip over any leading whitespace */
-    p = str;
+    const char *p = str;
 
     /* test for rgb value such as: "#ff0000"
        or rgba value such as "#ff000080" */
-    a = 255;			/* default alpha channel value=opaque in case not supplied */
-    bool is_rgb = *p == '#' && sscanf(p, "#%2x%2x%2x%2x", &r, &g, &b, &a) >= 3;
+    unsigned a = 255; // default alpha channel value=opaque in case not supplied
+    bool is_rgb = sscanf(p, "#%2x%2x%2x%2x", &r, &g, &b, &a) >= 3;
     if (!is_rgb) { // try 3 letter form
-	is_rgb = *p == '#' && strlen(p) == 4 && sscanf(p, "#%1x%1x%1x", &r, &g, &b) == 3;
+	is_rgb = strlen(p) == 4 && sscanf(p, "#%1x%1x%1x", &r, &g, &b) == 3;
 	if (is_rgb) {
 	    r |= r << 4;
 	    g |= g << 4;
@@ -341,36 +323,35 @@ int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
     char *name = resolveColor(str);
     if (!name)
 	return COLOR_MALLOC_FAIL;
-    if (last == NULL || strcasecmp(last->name, name)) {
-	last = bsearch(name, color_lib, sizeof(color_lib) / sizeof(hsvrgbacolor_t),
-	               sizeof(color_lib[0]), colorcmpf);
-    }
+    const hsvrgbacolor_t *known = bsearch(name, color_lib,
+                                          sizeof(color_lib) / sizeof(hsvrgbacolor_t),
+                                          sizeof(color_lib[0]), colorcmpf);
     free(name);
-    if (last != NULL) {
+    if (known != NULL) {
 	switch (target_type) {
 	case HSVA_DOUBLE:
-	    color->u.HSVA[0] = ((double) last->h) / 255.0;
-	    color->u.HSVA[1] = ((double) last->s) / 255.0;
-	    color->u.HSVA[2] = ((double) last->v) / 255.0;
-	    color->u.HSVA[3] = ((double) last->a) / 255.0;
+	    color->u.HSVA[0] = (double)known->h / 255.0;
+	    color->u.HSVA[1] = (double)known->s / 255.0;
+	    color->u.HSVA[2] = (double)known->v / 255.0;
+	    color->u.HSVA[3] = (double)known->a / 255.0;
 	    break;
 	case RGBA_BYTE:
-	    color->u.rgba[0] = last->r;
-	    color->u.rgba[1] = last->g;
-	    color->u.rgba[2] = last->b;
-	    color->u.rgba[3] = last->a;
+	    color->u.rgba[0] = known->r;
+	    color->u.rgba[1] = known->g;
+	    color->u.rgba[2] = known->b;
+	    color->u.rgba[3] = known->a;
 	    break;
 	case RGBA_WORD:
-	    color->u.rrggbbaa[0] = last->r * 65535 / 255;
-	    color->u.rrggbbaa[1] = last->g * 65535 / 255;
-	    color->u.rrggbbaa[2] = last->b * 65535 / 255;
-	    color->u.rrggbbaa[3] = last->a * 65535 / 255;
+	    color->u.rrggbbaa[0] = known->r * 65535 / 255;
+	    color->u.rrggbbaa[1] = known->g * 65535 / 255;
+	    color->u.rrggbbaa[2] = known->b * 65535 / 255;
+	    color->u.rrggbbaa[3] = known->a * 65535 / 255;
 	    break;
 	case RGBA_DOUBLE:
-	    color->u.RGBA[0] = last->r / 255.0;
-	    color->u.RGBA[1] = last->g / 255.0;
-	    color->u.RGBA[2] = last->b / 255.0;
-	    color->u.RGBA[3] = last->a / 255.0;
+	    color->u.RGBA[0] = known->r / 255.0;
+	    color->u.RGBA[1] = known->g / 255.0;
+	    color->u.RGBA[2] = known->b / 255.0;
+	    color->u.RGBA[3] = known->a / 255.0;
 	    break;
 	case COLOR_STRING:
 	    break;
