@@ -96,7 +96,6 @@ bool late_bool(void *obj, attrsym_t *attr, bool defaultValue) {
     return mapbool(agxget(obj, attr));
 }
 
-/* union-find */
 node_t *UF_find(node_t * n)
 {
     while (ND_UF_parent(n) && ND_UF_parent(n) != n) {
@@ -1335,9 +1334,7 @@ bool overlap_node(node_t *n, boxf b) {
 
 bool overlap_label(textlabel_t *lp, boxf b)
 {
-    pointf s;
-    s.x = lp->dimen.x / 2.;
-    s.y = lp->dimen.y / 2.;
+    const pointf s = {.x = lp->dimen.x / 2.0, .y = lp->dimen.y / 2.0};
     boxf bb = {.LL = sub_pointf(lp->pos, s), .UR = add_pointf(lp->pos, s)};
     return OVERLAP(b, bb);
 }
