@@ -10,7 +10,6 @@
 
 #include <assert.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <limits.h>
 #include <time.h>
 #include <dotgen/dot.h>
@@ -19,6 +18,7 @@
 #include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
+#include <util/alloc.h>
 #include <util/streq.h>
 
 static void
