@@ -30,18 +30,21 @@
 #endif
 #include <neatogen/kkutils.h>
 #include <common/pointset.h>
+#include <common/render.h>
+#include <common/utils.h>
 #include <neatogen/sgd.h>
-#include <cgraph/alloc.h>
-#include <cgraph/bitarray.h>
+#include <cgraph/agxbuf.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/startswith.h>
-#include <cgraph/strcasecmp.h>
-#include <cgraph/streq.h>
 #include <float.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/alloc.h>
+#include <util/bitarray.h>
+#include <util/prisize_t.h>
+#include <util/startswith.h>
+#include <util/strcasecmp.h>
+#include <util/streq.h>
 
 #ifndef HAVE_SRAND48
 #define srand48 srand
@@ -202,7 +205,7 @@ static cluster_data cluster_map(graph_t *mastergraph, graph_t *g) {
 
     cdata.ntoplevel = agnnodes(g);
     for (subg = agfstsubg(mastergraph); subg; subg = agnxtsubg(subg)) {
-        if (startswith(agnameof(subg), "cluster")) {
+        if (is_a_cluster(subg)) {
             nclusters++;
         }
     }
@@ -212,7 +215,7 @@ static cluster_data cluster_map(graph_t *mastergraph, graph_t *g) {
     cn = cdata.clustersizes = gv_calloc(nclusters, sizeof(int));
     for (subg = agfstsubg(mastergraph); subg; subg = agnxtsubg(subg)) {
         /* clusters are processed by separate calls to ordered_edges */
-        if (startswith(agnameof(subg), "cluster")) {
+        if (is_a_cluster(subg)) {
             int *c;
 
             *cn = agnnodes(subg);
@@ -476,7 +479,7 @@ dfs(Agraph_t * subg, Agraph_t * parentg, attrsym_t * G_lp, attrsym_t * G_bb)
 {
     boxf bb;
 
-    if (startswith(agnameof(subg), "cluster") && chkBB(subg, G_bb, &bb)) {
+    if (is_a_cluster(subg) && chkBB(subg, G_bb, &bb)) {
 	agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
 	GD_bb(subg) = bb;
 	add_cluster(parentg, subg);
@@ -950,7 +953,6 @@ static void initRegular(graph_t * G, int nG)
 int
 setSeed (graph_t * G, int dflt, long* seedp)
 {
-    char smallbuf[32];
     char *p = agget(G, "start");
     int init = dflt;
 
@@ -981,8 +983,10 @@ setSeed (graph_t * G, int dflt, long* seedp)
 #else
 	    seed = (unsigned) getpid() ^ (unsigned) time(NULL);
 #endif
-	    snprintf(smallbuf, sizeof(smallbuf), "%ld", seed);
-	    agset(G, "start", smallbuf);
+	    agxbuf buf = {0};
+	    agxbprint(&buf, "%ld", seed);
+	    agset(G, "start", agxbuse(&buf));
+	    agxbfree(&buf);
 	}
 	*seedp = seed;
     }
@@ -1367,7 +1371,7 @@ addCluster (graph_t* g)
 {
     graph_t *subg;
     for (subg = agfstsubg(agroot(g)); subg; subg = agnxtsubg(subg)) {
-	if (startswith(agnameof(subg), "cluster")) {
+	if (is_a_cluster(subg)) {
 	    agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
 	    add_cluster(g, subg);
 	    compute_bb(subg);
