@@ -10,9 +10,6 @@
 
 #define STANDALONE
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
-#include <cgraph/startswith.h>
-#include <cgraph/unreachable.h>
 #include <sparse/general.h>
 #include <sparse/DotIO.h>
 #include <sparse/clustering.h>
@@ -22,6 +19,9 @@
 #include <sparse/colorutil.h>
 #include <stdbool.h>
 #include <string.h>
+#include <util/alloc.h>
+#include <util/startswith.h>
+#include <util/unreachable.h>
 
 typedef struct {
     Agrec_t h;
@@ -302,7 +302,7 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
   int MAX_GRPS, MIN_GRPS;
   bool noclusterinfo = false;
   bool first = true;
-  float *pal;
+  const float *pal;
   int max_color = MAX_COLOR;
 
   switch (default_color_scheme){
@@ -322,11 +322,9 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
     pal = &(palette_pastel[0][0]);
     break;
   case COLOR_SCHEME_SEQUENTIAL_SINGLEHUE_RED:
-    fprintf(stderr," HERE!\n");
     pal = &(palette_sequential_singlehue_red[0][0]);
     break;
   case COLOR_SCHEME_SEQUENTIAL_SINGLEHUE_RED_LIGHTER:
-    fprintf(stderr," HERE!\n");
     pal = &(palette_sequential_singlehue_red_lighter[0][0]);
     break;
   case COLOR_SCHEME_PRIMARY:
