@@ -17,16 +17,13 @@
 #ifdef HAVE_SYS_MMAN_H
 #include <sys/mman.h>
 #endif
-#ifdef _MSC_VER
-#include <io.h>
-#endif
 
 #include <gvc/gvplugin_loadimage.h>
 #include <cgraph/agxbuf.h>
 #include <common/utils.h>
 #include <gvc/gvio.h>
+#include "core_loadimage_xdot.h"
 
-extern void core_loadimage_xdot(GVJ_t*, usershape_t*, boxf, bool);
 extern shape_desc *find_user_shape(char *name);
 
 typedef enum {
@@ -92,25 +89,21 @@ static void core_loadimage_fig(GVJ_t * job, usershape_t *us, boxf bf, bool fille
     int npoints = 5;
     int flipped = 0;
 
-    box b;
-
     assert(job);
     assert(us);
     assert(us->name);
 
-    BF2B(bf, b);
-
     gvprintf(job, "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d %d %d\n %d %s\n",
             object_code, sub_type, line_style, thickness, pen_color,
             fill_color, depth, pen_style, area_fill, style_val, join_style,
             cap_style, radius, forward_arrow, backward_arrow, npoints,
             flipped, us->name);
-    gvprintf(job," %d %d %d %d %d %d %d %d %d %d\n",
-	    b.LL.x, b.LL.y,
-	    b.LL.x, b.UR.y,
-	    b.UR.x, b.UR.y,
-	    b.UR.x, b.LL.y,
-	    b.LL.x, b.LL.y);
+    gvprintf(job," %.0f %.0f %.0f %.0f %.0f %.0f %.0f %.0f %.0f %.0f\n",
+	    bf.LL.x, bf.LL.y,
+	    bf.LL.x, bf.UR.y,
+	    bf.UR.x, bf.UR.y,
+	    bf.UR.x, bf.LL.y,
+	    bf.LL.x, bf.LL.y);
 }
 
 static void core_loadimage_vrml(GVJ_t * job, usershape_t *us, boxf b, bool filled)
@@ -176,7 +169,7 @@ static void core_loadimage_ps(GVJ_t * job, usershape_t *us, boxf b, bool filled)
 		fstat(fd, &statbuf);
 		us->datasize = (size_t)statbuf.st_size;
 #ifdef HAVE_SYS_MMAN_H
-		us->data = mmap(0, us->datasize, PROT_READ, MAP_SHARED, fd, 0);
+		us->data = mmap(0, us->datasize, PROT_READ, MAP_PRIVATE, fd, 0);
 		if (us->data == MAP_FAILED)
 			us->data = NULL;
 #else
