@@ -192,14 +192,14 @@ static vector<PointF> points(pointf *A, int n)
 	return newPoints;
 }
 
-static void gdiplusgen_path(GVJ_t *job, const GraphicsPath *path, int filled)
-{
+static void gdiplusgen_path(GVJ_t *job, const GraphicsPath &pathname,
+                            int filled) {
 	auto context = reinterpret_cast<Graphics *>(job->context);
 
 	/* fill the given path with job fill color */
 	if (filled) {
 		SolidBrush fill_brush(Color(job->obj->fillcolor.u.rgba [3], job->obj->fillcolor.u.rgba [0], job->obj->fillcolor.u.rgba [1], job->obj->fillcolor.u.rgba [2]));
-		context->FillPath(&fill_brush, path);
+		context->FillPath(&fill_brush, &pathname);
 	}
 
 	/* draw the given path from job pen color and pen width */
@@ -223,49 +223,49 @@ static void gdiplusgen_path(GVJ_t *job, const GraphicsPath *path, int filled)
 		break;
 	}
 
-	context->DrawPath(&draw_pen, path);
+	context->DrawPath(&draw_pen, &pathname);
 }
 
 static void gdiplusgen_ellipse(GVJ_t *job, pointf *A, int filled)
 {
 	/* convert ellipse into path */
-	GraphicsPath path;
+	GraphicsPath pathname;
 	double dx = A[1].x - A[0].x;
 	double dy = A[1].y - A[0].y;
-	path.AddEllipse(RectF(A[0].x - dx, -A[0].y - dy, dx * 2.0, dy * 2.0));
+	pathname.AddEllipse(RectF(A[0].x - dx, -A[0].y - dy, dx * 2.0, dy * 2.0));
 
 	/* draw the path */
-	gdiplusgen_path(job, &path, filled);
+	gdiplusgen_path(job, pathname, filled);
 }
 
 static void gdiplusgen_polygon(GVJ_t *job, pointf *A, size_t n, int filled) {
 	/* convert polygon into path */
-	GraphicsPath path;
+	GraphicsPath pathname;
 	assert(n <= INT_MAX);
-	path.AddPolygon(&points(A, n).front(), (int)n);
+	pathname.AddPolygon(&points(A, n).front(), (int)n);
 
 	/* draw the path */
-	gdiplusgen_path(job, &path, filled);
+	gdiplusgen_path(job, pathname, filled);
 }
 
 static void gdiplusgen_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
 	/* convert the beziers into path */
-	GraphicsPath path;
+	GraphicsPath pathname;
 	assert(n <= INT_MAX);
-	path.AddBeziers(&points(A, n).front(), (int)n);
+	pathname.AddBeziers(&points(A, n).front(), (int)n);
 
 	/* draw the path */
-	gdiplusgen_path(job, &path, filled);
+	gdiplusgen_path(job, pathname, filled);
 }
 
 static void gdiplusgen_polyline(GVJ_t *job, pointf *A, size_t n) {
 	/* convert the lines into path */
-	GraphicsPath path;
+	GraphicsPath pathname;
 	assert(n <= INT_MAX);
-	path.AddLines(&points(A,n).front(), (int)n);
+	pathname.AddLines(&points(A,n).front(), (int)n);
 
 	/* draw the path */
-	gdiplusgen_path(job, &path, 0);
+	gdiplusgen_path(job, pathname, 0);
 }
 
 static gvrender_engine_t gdiplusgen_engine = {
