@@ -163,9 +163,23 @@ def gvpr(program: Path) -> str:
     )
 
 
+def build_system() -> str:
+    """get the build system name"""
+    if platform.system() == "Windows":
+        return "cmake"
+    return os.getenv("build_system")
+
+
+def is_autotools() -> bool:
+    """was the Grapviz under test built with Autotools?"""
+    if platform.system() == "Windows":
+        return False
+    return not is_cmake()
+
+
 def is_cmake() -> bool:
     """was the Graphviz under test built with CMake?"""
-    return os.getenv("build_system") == "cmake"
+    return build_system() == "cmake"
 
 
 def is_macos() -> bool:
@@ -189,6 +203,18 @@ def is_static_build() -> bool:
     return False
 
 
+def is_ubuntu() -> bool:
+    """is the current environment Ubuntu?"""
+    return freedesktop_os_release().get("ID") == "ubuntu"
+
+
+def is_ubuntu_2004() -> bool:
+    """is the current environment Ubuntu 20.04?"""
+    if not is_ubuntu():
+        return False
+    return freedesktop_os_release().get("VERSION_ID") == "20.04"
+
+
 def remove_xtype_warnings(s: str) -> str:
     """
     Remove macOS XType warnings from a string. These appear to be harmless, but
