@@ -11,7 +11,7 @@ sys.path.append(os.path.dirname(__file__))
 from gvtest import run_c  # pylint: disable=wrong-import-position
 
 
-@pytest.mark.parametrize("utility", ("bitarray", "list", "tokenize"))
+@pytest.mark.parametrize("utility", ("list", "tokenize"))
 def test_utility(utility: str):
     """run the given utility’s unit tests"""
 
@@ -30,12 +30,30 @@ def test_utility(utility: str):
     _, _ = run_c(src, cflags=cflags)
 
 
+def test_bitarray():
+    """run bitarray’s unit tests"""
+
+    # locate the unit tests
+    src = Path(__file__).parent.resolve() / "../lib/util/test_bitarray.c"
+    assert src.exists()
+
+    # locate lib directory that needs to be in the include path
+    lib = Path(__file__).parent.resolve() / "../lib"
+
+    # extra C flags this compilation needs
+    cflags = ["-I", lib]
+    if platform.system() != "Windows":
+        cflags += ["-std=gnu99", "-Wall", "-Wextra", "-Werror"]
+
+    _, _ = run_c(src, cflags=cflags)
+
+
 @pytest.mark.parametrize("builtins", (False, True))
 def test_overflow_h(builtins: bool):
-    """test ../lib/cgraph/overflow.h"""
+    """test ../lib/util/overflow.h"""
 
     # locate the unit test
-    src = Path(__file__).parent.resolve() / "../lib/cgraph/test_overflow.c"
+    src = Path(__file__).parent.resolve() / "../lib/util/test_overflow.c"
     assert src.exists()
 
     # locate lib directory that needs to be in the include path
